# Bahasa Achya

Bahasa Achya adalah bahasa pemrograman yang terinspirasi dari sintaks Jakarta Selatan (Jaksel). Dengan menggunakan Achya, Anda dapat menulis kode Python dengan gaya Jaksel!

## Instalasi

Untuk menginstal Bahasa Achya, cukup jalankan perintah berikut:

```bash
pip install bahasa-achya
```

## Penggunaan

Setelah menginstal, Anda dapat menggunakan perintah `achya` untuk mentranspile kode Achya (.al) menjadi kode Python (.py).

Contoh:

```bash
achya contoh_program.al
```

Untuk menginstal paket seperti `pandas`, gunakan perintah `achya install`:

```bash
achya install pandas
```
